'use strict';
var controller = module.exports;
/*
/////////////////////////
Example controller
/////////////////////////
*/

/*
  Functions in a127 controllers used for operations should take two parameters:

  Param 1: a handle to the request object
  Param 2: a handle to the response object
 */
var util = require('util');
controller["get"] = function example_operation(req, res) {
  // variables defined in the Swagger document can be referenced using req.swagger.params.{parameter_name}
  var name = req.swagger.params.name.value || 'stranger';
  var hello = util.format('Hello, %s!', name);

  // this sends back a JSON response which is a single string
  res.json(hello);
}

/* req has a swagger attribute, documented below: 

                req.swagger

The structure of req.swagger is as follows:

- apiPath: string The API's path (The key used in the paths object for the corresponding API)
- path: object The corresponding path in the Swagger object that the request maps to
- operation: object The corresponding operation in the API Declaration that the request maps to
- operationParameters: object[] The computed parameters for this operation
- operationPath: string[] The path to the operation
- params: object For each of the request parameters defined in your Swagger document, its path, its schema and its processed value. (In the event the value needs coercion and it cannot be converted, the value property will be the original value provided.)
- security: object[] The computed security for this request
- swaggerObject: object The Swagger object
- useStubs: boolean Whether or not stubs have been turned on.
*/